# teralytic
The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io` 

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.6
- Package version: 1.0.6-6
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import teralytic 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import teralytic
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import teralytic
from teralytic.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = teralytic.Configuration()
configuration.api_key['x-api-key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['x-api-key'] = 'Bearer'
# Configure OAuth2 access token for authorization: OAuth2
configuration = teralytic.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = teralytic.OrganizationApi(teralytic.ApiClient(configuration))
organization_id = 'organization_id_example' # str | id of Organization for the operation
application = teralytic.Application() # Application | The application to create (optional)

try:
    # Create a new organization client with the specified scope
    api_response = api_instance.application_create(organization_id, application=application)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling OrganizationApi->application_create: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.teralytic.io/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*OrganizationApi* | [**application_create**](docs/OrganizationApi.md#application_create) | **POST** /organizations/{organization_id}/applications | Create a new organization client with the specified scope
*OrganizationApi* | [**application_delete**](docs/OrganizationApi.md#application_delete) | **DELETE** /organizations/{organization_id}/applications/{application_id} | Delete an application api client
*OrganizationApi* | [**application_list**](docs/OrganizationApi.md#application_list) | **GET** /organizations/{organization_id}/applications | Get organization applications
*OrganizationApi* | [**field_get**](docs/OrganizationApi.md#field_get) | **GET** /organizations/{organization_id}/fields/{field_id} | List single Field details associated with Field id provided (from set of Fields associated with the account key)
*OrganizationApi* | [**field_list**](docs/OrganizationApi.md#field_list) | **GET** /organizations/{organization_id}/fields | List all Fields associated with account key
*OrganizationApi* | [**organization_get**](docs/OrganizationApi.md#organization_get) | **GET** /organizations/{organization_id} | Get a specific organization
*OrganizationApi* | [**organization_list**](docs/OrganizationApi.md#organization_list) | **GET** /organizations | List all Organizations
*OrganizationApi* | [**probe_get**](docs/OrganizationApi.md#probe_get) | **GET** /organizations/{organization_id}/probes/{probe_id} | List single Probe details, including Reading data, associated with Probe id provided (from set of Fields associated with the account key)
*OrganizationApi* | [**probe_list**](docs/OrganizationApi.md#probe_list) | **GET** /organizations/{organization_id}/probes | List all Probes associated with account key
*ReadingsApi* | [**analytics_query**](docs/ReadingsApi.md#analytics_query) | **GET** /organizations/{organization_id}/analytics | Query reading anlaytics
*ReadingsApi* | [**readings_query**](docs/ReadingsApi.md#readings_query) | **GET** /organizations/{organization_id}/readings | Query sensor readings


## Documentation For Models

 - [Application](docs/Application.md)
 - [Error](docs/Error.md)
 - [Field](docs/Field.md)
 - [FieldGeometry](docs/FieldGeometry.md)
 - [FieldGeometryGeometry](docs/FieldGeometryGeometry.md)
 - [OrgRole](docs/OrgRole.md)
 - [Organization](docs/Organization.md)
 - [Probe](docs/Probe.md)
 - [PropertyRole](docs/PropertyRole.md)
 - [Reading](docs/Reading.md)
 - [ReadingData](docs/ReadingData.md)
 - [ReadingLocation](docs/ReadingLocation.md)
 - [ReadingType](docs/ReadingType.md)
 - [RolePermission](docs/RolePermission.md)
 - [StringArray](docs/StringArray.md)
 - [UUIDArray](docs/UUIDArray.md)
 - [User](docs/User.md)
 - [MicroClimateData](docs/MicroClimateData.md)
 - [SensorData](docs/SensorData.md)
 - [WeatherData](docs/WeatherData.md)


## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header

## OAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - **https://api.teralytic.io/organization.read**: Read organization properties
 - **https://api.teralytic.io/organization.write**: Write organization properties
 - **https://api.teralytic.io/organization.admin**: Administer organization properties
 - **https://api.teralytic.io/reading.read**: Query readings scope


## Author



